componenttools.component_to_parentage_signature
===============================================

.. autofunction:: abjad.tools.componenttools.component_to_parentage_signature.component_to_parentage_signature
